# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`clickhouse::client`](#clickhouse--client): Installs and configures Clickhouse client.
* [`clickhouse::repo`](#clickhouse--repo): Installs repository for Clickhouse.
* [`clickhouse::server`](#clickhouse--server): Installs and configures Clickhouse server.

#### Private Classes

* `clickhouse::client::install`: Private class for managing Clickhouse client package.
* `clickhouse::params`: Private class for setting default Clickhouse parameters.
* `clickhouse::server::config`: Private class for Clickhouse server configuration.
* `clickhouse::server::install`: Private class for managing Clickhouse server package.
* `clickhouse::server::resources`: Private class for applying Clickhouse resources.
* `clickhouse::server::service`: Private class for managing the Clickhouse service.

### Defined types

* [`clickhouse::server::dictionary`](#clickhouse--server--dictionary): Create and manage Clickhouse dictionary.
* [`clickhouse::server::macros`](#clickhouse--server--macros): Create and manage Clickhouse macros file for replication.
* [`clickhouse::server::profiles`](#clickhouse--server--profiles): Create and manage Clickhouse profiles.
* [`clickhouse::server::quotas`](#clickhouse--server--quotas): Create and manage Clickhouse quotas.
* [`clickhouse::server::remote_servers`](#clickhouse--server--remote_servers): Create and manage Clickhouse remote servers for Distributed engine.
* [`clickhouse::server::user`](#clickhouse--server--user): Create and manage Clickhouse user.

### Resource types

* [`clickhouse_database`](#clickhouse_database): Manages a Clickhouse database.

### Functions

* [`clickhouse_config`](#clickhouse_config): Convert hash to Clickhouse XML config.

### Data types

* [`Clickhouse::Clickhouse_crash_reports`](#Clickhouse--Clickhouse_crash_reports): lint:ignore:2sp_soft_tabs
* [`Clickhouse::Clickhouse_networks`](#Clickhouse--Clickhouse_networks): lint:ignore:2sp_soft_tabs
* [`Clickhouse::Clickhouse_quotas`](#Clickhouse--Clickhouse_quotas): lint:ignore:2sp_soft_tabs
* [`Clickhouse::Clickhouse_remote_servers`](#Clickhouse--Clickhouse_remote_servers): lint:ignore:2sp_soft_tabs, lint:ignore:140chars
* [`Clickhouse::Clickhouse_replication`](#Clickhouse--Clickhouse_replication): lint:ignore:2sp_soft_tabs
* [`Clickhouse::Clickhouse_users`](#Clickhouse--Clickhouse_users): lint:ignore:2sp_soft_tabs

## Classes

### <a name="clickhouse--client"></a>`clickhouse::client`

Installs and configures Clickhouse client.

#### Examples

##### Install Clickhouse client

```puppet
class { 'clickhouse::client':
  package_name   => 'clickhouse-client',
  package_ensure => 'present',
}
```

#### Parameters

The following parameters are available in the `clickhouse::client` class:

* [`manage_repo`](#-clickhouse--client--manage_repo)
* [`package_name`](#-clickhouse--client--package_name)
* [`package_ensure`](#-clickhouse--client--package_ensure)
* [`manage_package`](#-clickhouse--client--manage_package)
* [`package_install_options`](#-clickhouse--client--package_install_options)

##### <a name="-clickhouse--client--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Whether to install Clickhouse repository. Defaults to 'true'.

Default value: `$clickhouse::params::manage_repo`

##### <a name="-clickhouse--client--package_name"></a>`package_name`

Data type: `String`

Name of Clickhouse client package to install. Defaults to 'clickhouse-client'.

Default value: `$clickhouse::params::client_package_name`

##### <a name="-clickhouse--client--package_ensure"></a>`package_ensure`

Data type: `String`

Whether the Clickhouse client package should be present, absent or specific version.
Valid values are 'present', 'absent' or 'x.y.z'. Defaults to 'present'.

Default value: `$clickhouse::params::client_package_ensure`

##### <a name="-clickhouse--client--manage_package"></a>`manage_package`

Data type: `Boolean`

Whether to manage Clickhouse client package. Defaults to 'true'.

Default value: `$clickhouse::params::client_manage_package`

##### <a name="-clickhouse--client--package_install_options"></a>`package_install_options`

Data type: `Array[String]`

Array of install options for managed package resources. Appropriate options are passed to package manager.

Default value: `$clickhouse::params::client_package_install_options`

### <a name="clickhouse--repo"></a>`clickhouse::repo`

Installs repository for Clickhouse.

#### Examples

##### 

```puppet
include clickhouse::repo
```

### <a name="clickhouse--server"></a>`clickhouse::server`

Installs and configures Clickhouse server.

#### Examples

##### Install Clickhouse Server.

```puppet
class { 'clickhouse::server':
  package_name   => 'clickhouse-server',
  package_ensure => '19.1.6-1.el7',
}
```

#### Parameters

The following parameters are available in the `clickhouse::server` class:

* [`manage_repo`](#-clickhouse--server--manage_repo)
* [`package_name`](#-clickhouse--server--package_name)
* [`package_ensure`](#-clickhouse--server--package_ensure)
* [`manage_package`](#-clickhouse--server--manage_package)
* [`package_install_options`](#-clickhouse--server--package_install_options)
* [`manage_config`](#-clickhouse--server--manage_config)
* [`config_dir`](#-clickhouse--server--config_dir)
* [`users_dir`](#-clickhouse--server--users_dir)
* [`dict_dir`](#-clickhouse--server--dict_dir)
* [`clickhouse_datadir`](#-clickhouse--server--clickhouse_datadir)
* [`clickhouse_tmpdir`](#-clickhouse--server--clickhouse_tmpdir)
* [`clickhouse_user`](#-clickhouse--server--clickhouse_user)
* [`clickhouse_group`](#-clickhouse--server--clickhouse_group)
* [`keep_default_users`](#-clickhouse--server--keep_default_users)
* [`override_options`](#-clickhouse--server--override_options)
* [`config_file`](#-clickhouse--server--config_file)
* [`profiles_file`](#-clickhouse--server--profiles_file)
* [`quotas_file`](#-clickhouse--server--quotas_file)
* [`macros_file`](#-clickhouse--server--macros_file)
* [`zookeeper_config_file`](#-clickhouse--server--zookeeper_config_file)
* [`remote_servers_file`](#-clickhouse--server--remote_servers_file)
* [`dict_source_folder`](#-clickhouse--server--dict_source_folder)
* [`install_client`](#-clickhouse--server--install_client)
* [`service_name`](#-clickhouse--server--service_name)
* [`service_ensure`](#-clickhouse--server--service_ensure)
* [`service_enabled`](#-clickhouse--server--service_enabled)
* [`manage_service`](#-clickhouse--server--manage_service)
* [`restart`](#-clickhouse--server--restart)
* [`users`](#-clickhouse--server--users)
* [`profiles`](#-clickhouse--server--profiles)
* [`quotas`](#-clickhouse--server--quotas)
* [`dictionaries`](#-clickhouse--server--dictionaries)
* [`replication`](#-clickhouse--server--replication)
* [`remote_servers`](#-clickhouse--server--remote_servers)
* [`crash_reports`](#-clickhouse--server--crash_reports)
* [`main_dir`](#-clickhouse--server--main_dir)
* [`manage_systemd`](#-clickhouse--server--manage_systemd)

##### <a name="-clickhouse--server--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Whether to install Clickhouse repository. Defaults to 'true'.

Default value: `$clickhouse::params::manage_repo`

##### <a name="-clickhouse--server--package_name"></a>`package_name`

Data type: `String`

Name of Clickhouse Server package to install. Defaults to 'clickhouse-server'.

Default value: `$clickhouse::params::package_name`

##### <a name="-clickhouse--server--package_ensure"></a>`package_ensure`

Data type: `String`

Whether the Clickhouse Server package should be present, absent or specific version.
Valid values are 'present', 'absent' or 'x.y.z'. Defaults to 'present'.

Default value: `$clickhouse::params::package_ensure`

##### <a name="-clickhouse--server--manage_package"></a>`manage_package`

Data type: `Boolean`

Whether to manage Clickhouse Server package. Defaults to 'true'.

Default value: `$clickhouse::params::manage_package`

##### <a name="-clickhouse--server--package_install_options"></a>`package_install_options`

Data type: `Array[String]`

Array of install options for managed package resources. Appropriate options are passed to package manager.

Default value: `$clickhouse::params::package_install_options`

##### <a name="-clickhouse--server--manage_config"></a>`manage_config`

Data type: `Boolean`

Whether the Clickhouse Server configurations files should be managd. Defaults to 'true'.

Default value: `$clickhouse::params::manage_config`

##### <a name="-clickhouse--server--config_dir"></a>`config_dir`

Data type: `Stdlib::Unixpath`

Directory where Clickhouse Server configuration files will be stored. Defaults to '/etc/clickhouse-server/conf.d'.

Default value: `$clickhouse::params::config_dir`

##### <a name="-clickhouse--server--users_dir"></a>`users_dir`

Data type: `Stdlib::Unixpath`

Directory where Clickhouse Server user configuration files will be stored. Defaults to '/etc/clickhouse-server/users.d'.

Default value: `$clickhouse::params::users_dir`

##### <a name="-clickhouse--server--dict_dir"></a>`dict_dir`

Data type: `Stdlib::Unixpath`

Directory where Clickhouse Server dictionaries will be stored. Defaults to '/etc/clickhouse-server/dict'.

Default value: `$clickhouse::params::dict_dir`

##### <a name="-clickhouse--server--clickhouse_datadir"></a>`clickhouse_datadir`

Data type: `Stdlib::Unixpath`

Directory where Clickhouse Server database files will be stored. Defaults to '/var/lib/clickhouse/'.

Default value: `$clickhouse::params::clickhouse_datadir`

##### <a name="-clickhouse--server--clickhouse_tmpdir"></a>`clickhouse_tmpdir`

Data type: `Stdlib::Unixpath`

Directory where Clickhouse Server tmp files will be stored. Defaults to '/var/lib/clickhouse/tmp/'.

Default value: `$clickhouse::params::clickhouse_tmpdir`

##### <a name="-clickhouse--server--clickhouse_user"></a>`clickhouse_user`

Data type: `String`

Owner for Clickhouse Server configuration and data directories. Defaults to 'clickhouse'.

Default value: `$clickhouse::params::clickhouse_user`

##### <a name="-clickhouse--server--clickhouse_group"></a>`clickhouse_group`

Data type: `String`

Group for Clickhouse Server configuration and data directories. Defaults to 'clickhouse'.

Default value: `$clickhouse::params::clickhouse_group`

##### <a name="-clickhouse--server--keep_default_users"></a>`keep_default_users`

Data type: `Boolean`

Specifies whether to automatically remove default users, which are specified in users.xml file. Defaults to 'false'.

Default value: `$clickhouse::params::keep_default_users`

##### <a name="-clickhouse--server--override_options"></a>`override_options`

Data type: `Hash[String, Any]`

Hash[String, Any] of override options to pass to Clickhouse Server configuration file.

Default value: `{}`

##### <a name="-clickhouse--server--config_file"></a>`config_file`

Data type: `String`

Name of the file, where Clickhouse Server configuration will be stored. See https://clickhouse.yandex/docs/en/operations/configuration_files/. Defaults to 'config.xml'

Default value: `$clickhouse::params::config_file`

##### <a name="-clickhouse--server--profiles_file"></a>`profiles_file`

Data type: `String`

Name of the file, where Clickhouse Server profiles configuration will be stored. See https://clickhouse.yandex/docs/en/operations/settings/settings_profiles/. Defaults to '$profiles.xml'.

Default value: `$clickhouse::params::profiles_file`

##### <a name="-clickhouse--server--quotas_file"></a>`quotas_file`

Data type: `String`

Name of the file, where Clickhouse Server quotas configuration will be stored. See https://clickhouse.yandex/docs/en/operations/quotas/.  Defaults to 'quotas.xml'.

Default value: `$clickhouse::params::quotas_file`

##### <a name="-clickhouse--server--macros_file"></a>`macros_file`

Data type: `String`

Name of the file, where Clickhouse Server macros configuration for replication will be stored. See https://clickhouse.yandex/docs/en/operations/table_engines/replication/. Defaults to '$macros.xml'.

Default value: `$clickhouse::params::macros_file`

##### <a name="-clickhouse--server--zookeeper_config_file"></a>`zookeeper_config_file`

Data type: `String`

Name of the file, where Clickhouse Server zookeeper configuration will be stored. See https://clickhouse.yandex/docs/en/operations/table_engines/replication/.  Defaults to 'zookeeper.xml'.

Default value: `$clickhouse::params::zookeeper_config_file`

##### <a name="-clickhouse--server--remote_servers_file"></a>`remote_servers_file`

Data type: `String`

Name of the file, where Clickhouse Server remote servers configuration for Distributed table engine will be stored. See https://clickhouse.yandex/docs/en/operations/table_engines/distributed/. Defaults to 'remote_servers.xml'.

Default value: `$clickhouse::params::remote_servers_file`

##### <a name="-clickhouse--server--dict_source_folder"></a>`dict_source_folder`

Data type: `String`

Path to a 'files' folder in puppet, where dictionary file are located. Defaults to 'puppet:///modules/${module_name}'.

Default value: `$clickhouse::params::dict_source_folder`

##### <a name="-clickhouse--server--install_client"></a>`install_client`

Data type: `Boolean`

Specifies whether to install Clickhouse Client package. Defaults to 'true'.

Default value: `$clickhouse::params::install_client`

##### <a name="-clickhouse--server--service_name"></a>`service_name`

Data type: `String`

Name of the Clickhouse Server service. Defaults to 'clickhouse-server'.

Default value: `$clickhouse::params::service_name`

##### <a name="-clickhouse--server--service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Specifies whether Clickhouse Server service should be running. Defaults to 'running'.

Default value: `$clickhouse::params::service_ensure`

##### <a name="-clickhouse--server--service_enabled"></a>`service_enabled`

Data type: `Boolean`

Specifies whether Clickhouse Server service should be enabled. Defaults to 'true'.

Default value: `$clickhouse::params::service_enabled`

##### <a name="-clickhouse--server--manage_service"></a>`manage_service`

Data type: `Boolean`

Specifies whether Clickhouse Server service should be managed. Defaults to 'true'.

Default value: `$clickhouse::params::manage_service`

##### <a name="-clickhouse--server--restart"></a>`restart`

Data type: `Boolean`

Specifies whether Clickhouse Server service should be restated when configuration changes. Defaults to 'false'.

Default value: `$clickhouse::params::restart`

##### <a name="-clickhouse--server--users"></a>`users`

Data type: `Optional[Clickhouse::Clickhouse_users]`

Users, which are passed to clickhouse::server::user (see types/clickhouse_users.pp for data type description). See https://clickhouse.yandex/docs/en/operations/access_rights/.

Default value: `undef`

##### <a name="-clickhouse--server--profiles"></a>`profiles`

Data type: `Optional[Hash[String, Hash[String, Any]]]`

Profiles configuration, which are passed to clickhouse::server::profiles. See https://clickhouse.yandex/docs/en/operations/settings/settings_profiles/.

Default value: `undef`

##### <a name="-clickhouse--server--quotas"></a>`quotas`

Data type: `Optional[Clickhouse::Clickhouse_quotas]`

Quotas configuration, which are passed to clickhouse::server::quotas. See https://clickhouse.yandex/docs/en/operations/quotas/.

Default value: `undef`

##### <a name="-clickhouse--server--dictionaries"></a>`dictionaries`

Data type: `Optional[Array[String]]`

Dictionaries configuration, which are passed to clickhouse::server::dictionary. See https://clickhouse.yandex/docs/en/query_language/dicts/external_dicts/.

Default value: `undef`

##### <a name="-clickhouse--server--replication"></a>`replication`

Data type: `Optional[Clickhouse::Clickhouse_replication]`

Replication configuration parameters (see types/clickhouse_replication.pp for data type description). See https://clickhouse.yandex/docs/en/operations/table_engines/replication/.

Default value: `undef`

##### <a name="-clickhouse--server--remote_servers"></a>`remote_servers`

Data type: `Optional[Clickhouse::Clickhouse_remote_servers]`

Remote server configuration parameters for Distributed engine (see types/clickhouse_remote_servers.pp for data type description), which are passed to clickhouse::server::remote_servers. See https://clickhouse.yandex/docs/en/operations/table_engines/distributed/.

Default value: `undef`

##### <a name="-clickhouse--server--crash_reports"></a>`crash_reports`

Data type: `Optional[Clickhouse::Clickhouse_crash_reports]`



Default value: `undef`

##### <a name="-clickhouse--server--main_dir"></a>`main_dir`

Data type: `Stdlib::Unixpath`



Default value: `$clickhouse::params::main_dir`

##### <a name="-clickhouse--server--manage_systemd"></a>`manage_systemd`

Data type: `Boolean`



Default value: `$clickhouse::params::manage_systemd`

## Defined types

### <a name="clickhouse--server--dictionary"></a>`clickhouse::server::dictionary`

Create and manage Clickhouse dictionary.

* **See also**
  * https://clickhouse.yandex/docs/en/query_language/dicts/external_dicts/

#### Examples

##### Create a basic Clickhouse dictionary:

```puppet
clickhouse::server::dictionary { 'countries.xml':
  source => 'puppet:///modules/clickhouse/dictionaries',
}
```

#### Parameters

The following parameters are available in the `clickhouse::server::dictionary` defined type:

* [`name`](#-clickhouse--server--dictionary--name)
* [`dict_dir`](#-clickhouse--server--dictionary--dict_dir)
* [`dict_file_owner`](#-clickhouse--server--dictionary--dict_file_owner)
* [`dict_file_group`](#-clickhouse--server--dictionary--dict_file_group)
* [`ensure`](#-clickhouse--server--dictionary--ensure)
* [`source`](#-clickhouse--server--dictionary--source)

##### <a name="-clickhouse--server--dictionary--name"></a>`name`

Name of the dictionary file in the $source and $dict_dir folders.

##### <a name="-clickhouse--server--dictionary--dict_dir"></a>`dict_dir`

Data type: `Stdlib::Unixpath`

Path to folder with clickhouse dictionaries. Defaults to '/etc/clickhouse-server/dict'.

Default value: `$clickhouse::server::dict_dir`

##### <a name="-clickhouse--server--dictionary--dict_file_owner"></a>`dict_file_owner`

Data type: `String`

Owner of the dictionary file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_user`

##### <a name="-clickhouse--server--dictionary--dict_file_group"></a>`dict_file_group`

Data type: `String`

Group of the dictionary file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_group`

##### <a name="-clickhouse--server--dictionary--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether to create dictionary. Valid values are 'present', 'absent'. Defaults to 'present'.

Default value: `'present'`

##### <a name="-clickhouse--server--dictionary--source"></a>`source`

Data type: `String`

Path to a 'files' folder in puppet, where dictionary file are located. Defaults to 'puppet:///modules/${module_name}'.

Default value: `"${clickhouse::server::dict_source_folder}/${title}"`

### <a name="clickhouse--server--macros"></a>`clickhouse::server::macros`

Create and manage Clickhouse macros file for replication.

* **See also**
  * https://clickhouse.yandex/docs/en/operations/table_engines/replication/

#### Examples

##### Create macros file /etc/clickhouse-server/conf.d/macros.xml with substitutions for cluster, replica and shard

```puppet
clickhouse::server::macros { 'macros.xml':
    config_folder => '/etc/clickhouse-server/conf.d',
    macros        => {
      cluster => 'Clickhouse_cluster',
      replica => 'myhost.local',
      shard   => '1',
    },
}
```

#### Parameters

The following parameters are available in the `clickhouse::server::macros` defined type:

* [`name`](#-clickhouse--server--macros--name)
* [`config_dir`](#-clickhouse--server--macros--config_dir)
* [`macros_file_owner`](#-clickhouse--server--macros--macros_file_owner)
* [`macros_file_group`](#-clickhouse--server--macros--macros_file_group)
* [`ensure`](#-clickhouse--server--macros--ensure)
* [`macros`](#-clickhouse--server--macros--macros)

##### <a name="-clickhouse--server--macros--name"></a>`name`

Name of the file with macros configurations.

##### <a name="-clickhouse--server--macros--config_dir"></a>`config_dir`

Data type: `Stdlib::Unixpath`

Path to Clickhouse configuration folder. Defaults to '/etc/clickhouse-server/conf.d'.

Default value: `$clickhouse::server::config_dir`

##### <a name="-clickhouse--server--macros--macros_file_owner"></a>`macros_file_owner`

Data type: `String`

Owner of the macros file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_user`

##### <a name="-clickhouse--server--macros--macros_file_group"></a>`macros_file_group`

Data type: `String`

Group of the macros file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_group`

##### <a name="-clickhouse--server--macros--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether to create macros file. Valid values are 'present', 'absent'. Defaults to 'present'.

Default value: `'present'`

##### <a name="-clickhouse--server--macros--macros"></a>`macros`

Data type: `Hash[String, Any]`

Substitions in macros file.

Default value: `{}`

### <a name="clickhouse--server--profiles"></a>`clickhouse::server::profiles`

Create and manage Clickhouse profiles.

* **See also**
  * https://clickhouse.yandex/docs/en/operations/settings/settings_profiles/

#### Examples

##### Create two profiles (web and readonly), which will be stored in /etc/clickhouse-server/users.d/profiles.xml file.

```puppet
clickhouse::server::profiles { 'profiles.xml':
  config_dir    => '/etc/clickhouse-server/users.d',
  profiles      => {
    web      => {
      max_threads      => 8,
      max_rows_to_read => 1000000000,
    },
    readonly => {
       readonly => 1,
    },
  },
}
```

#### Parameters

The following parameters are available in the `clickhouse::server::profiles` defined type:

* [`name`](#-clickhouse--server--profiles--name)
* [`config_dir`](#-clickhouse--server--profiles--config_dir)
* [`profiles_file_owner`](#-clickhouse--server--profiles--profiles_file_owner)
* [`profiles_file_group`](#-clickhouse--server--profiles--profiles_file_group)
* [`ensure`](#-clickhouse--server--profiles--ensure)
* [`profiles`](#-clickhouse--server--profiles--profiles)

##### <a name="-clickhouse--server--profiles--name"></a>`name`

Name of the file with profiles configurations.

##### <a name="-clickhouse--server--profiles--config_dir"></a>`config_dir`

Data type: `Stdlib::Unixpath`

Path to Clickhouse configuration folder. Defaults to '/etc/clickhouse-server/conf.d'.

Default value: `$clickhouse::server::config_dir`

##### <a name="-clickhouse--server--profiles--profiles_file_owner"></a>`profiles_file_owner`

Data type: `String`

Owner of the profiles file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_user`

##### <a name="-clickhouse--server--profiles--profiles_file_group"></a>`profiles_file_group`

Data type: `String`

Group of the profiles file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_group`

##### <a name="-clickhouse--server--profiles--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether to create profiles file. Valid values are 'present', 'absent'. Defaults to 'present'.

Default value: `'present'`

##### <a name="-clickhouse--server--profiles--profiles"></a>`profiles`

Data type: `Hash[String, Hash[String, Any]]`

Profiles configuration.

Default value: `{}`

### <a name="clickhouse--server--quotas"></a>`clickhouse::server::quotas`

Create and manage Clickhouse quotas.

* **See also**
  * https://clickhouse.yandex/docs/en/operations/quotas/

#### Examples

##### Create two quotas (web with two intervals, office with one).

```puppet
clickhouse::server::quotas { 'quotas.xml':
  config_dir   => '/etc/clickhouse-server/users.d',
  quotas => {
    web => {
      interval => [
        {
          duration       => 3600,
          queries        => 2,
          errors         => 5,
          result_rows    => 1000,
          read_rows      => 1000,
          execution_time => 5000,
        },
        {
          duration       => 86400,
          queries        => 2000,
          errors         => 50,
          result_rows    => 10000,
          read_rows      => 10000,
          execution_time => 50000,
        },
      ],
    },
    office => {
      interval => [
        {
          duration       => 3600,
          queries        => 256,
          errors         => 50,
          result_rows    => 3000,
          read_rows      => 3000,
          execution_time => 5000,
        }
      ],
    },
  },
}
```

#### Parameters

The following parameters are available in the `clickhouse::server::quotas` defined type:

* [`name`](#-clickhouse--server--quotas--name)
* [`users_dir`](#-clickhouse--server--quotas--users_dir)
* [`quotas_file_owner`](#-clickhouse--server--quotas--quotas_file_owner)
* [`quotas_file_group`](#-clickhouse--server--quotas--quotas_file_group)
* [`ensure`](#-clickhouse--server--quotas--ensure)
* [`quotas`](#-clickhouse--server--quotas--quotas)

##### <a name="-clickhouse--server--quotas--name"></a>`name`

Name of the file with quotas configurations.

##### <a name="-clickhouse--server--quotas--users_dir"></a>`users_dir`

Data type: `Stdlib::Unixpath`

Path to Clickhouse configuration folder. Defaults to '/etc/clickhouse-server/users.d'.

Default value: `$clickhouse::server::config_dir`

##### <a name="-clickhouse--server--quotas--quotas_file_owner"></a>`quotas_file_owner`

Data type: `String`

Owner of the quotas file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_user`

##### <a name="-clickhouse--server--quotas--quotas_file_group"></a>`quotas_file_group`

Data type: `String`

Group of the quotas file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_group`

##### <a name="-clickhouse--server--quotas--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether to create quotas file. Valid values are 'present', 'absent'. Defaults to 'present'.

Default value: `'present'`

##### <a name="-clickhouse--server--quotas--quotas"></a>`quotas`

Data type: `Clickhouse::Clickhouse_quotas`

Quotas configuraion.

Default value: `{}`

### <a name="clickhouse--server--remote_servers"></a>`clickhouse::server::remote_servers`

Create and manage Clickhouse remote servers for Distributed engine.

* **See also**
  * https://clickhouse.yandex/docs/en/operations/table_engines/distributed/

#### Examples

##### Create three Clickhouse clusters. Replicated - one shard with two replicas, segmented - two shards without replicas, segmented_replicated - two shards, each having two replicas.

```puppet
clickhouse::server::remote_servers { 'remote_servers.xml':
  remote_servers_file => '/etc/clickhouse-server/conf.d',
  remote_servers => {
    replicated           => {
      shard => {
        weight               => 1,
        internal_replication => true,
        replica              => ['host1.local:9000', 'host2.local:9000'],
      }
    },
    segmented            => {
      shard1 => {
        internal_replication => true,
        replica              => ['host1.local:9000'],
      },
      shard2 => {
        internal_replication => true,
        replica              => ['host2.local:9000'],
      }
    },
    segmented_replicated => {
      shard1 => {
        internal_replication => true,
        replica              => ['host1.local:9000', 'host2.local:9000'],
      },
      shard2 => {
        internal_replication => true,
        replica              => ['host3.local:9000', 'host4.local:9000'],
      }
    },
  },
}
```

#### Parameters

The following parameters are available in the `clickhouse::server::remote_servers` defined type:

* [`name`](#-clickhouse--server--remote_servers--name)
* [`config_dir`](#-clickhouse--server--remote_servers--config_dir)
* [`remote_servers_file_owner`](#-clickhouse--server--remote_servers--remote_servers_file_owner)
* [`remote_servers_file_group`](#-clickhouse--server--remote_servers--remote_servers_file_group)
* [`ensure`](#-clickhouse--server--remote_servers--ensure)
* [`remote_servers`](#-clickhouse--server--remote_servers--remote_servers)

##### <a name="-clickhouse--server--remote_servers--name"></a>`name`

Name of the file with remote servers configurations.

##### <a name="-clickhouse--server--remote_servers--config_dir"></a>`config_dir`

Data type: `Stdlib::Unixpath`

Path to Clickhouse configuration folder. Defaults to '/etc/clickhouse-server/conf.d'.

Default value: `$clickhouse::server::config_dir`

##### <a name="-clickhouse--server--remote_servers--remote_servers_file_owner"></a>`remote_servers_file_owner`

Data type: `String`

Owner of the remote servers file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_user`

##### <a name="-clickhouse--server--remote_servers--remote_servers_file_group"></a>`remote_servers_file_group`

Data type: `String`

Group of the remote servers file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_group`

##### <a name="-clickhouse--server--remote_servers--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether to create remote servers file. Valid values are 'present', 'absent'. Defaults to 'present'.

Default value: `'present'`

##### <a name="-clickhouse--server--remote_servers--remote_servers"></a>`remote_servers`

Data type: `Clickhouse::Clickhouse_remote_servers`

Remote server configurations (see types/clickhouse_remote_servers.pp for data type description).

Default value: `{}`

### <a name="clickhouse--server--user"></a>`clickhouse::server::user`

Create and manage Clickhouse user.

* **See also**
  * https://clickhouse.yandex/docs/en/operations/access_rights/

#### Examples

##### Create Clickhouse user.

```puppet
clickhouse::server::user { 'alice':
  password        => 'HelloAlice',
  quota           => 'default',
  profile         => 'default',
  allow_databases => ['web', 'data'],
  networks        => {
    ip => ['::/0'],
  },
}
```

#### Parameters

The following parameters are available in the `clickhouse::server::user` defined type:

* [`name`](#-clickhouse--server--user--name)
* [`password`](#-clickhouse--server--user--password)
* [`quota`](#-clickhouse--server--user--quota)
* [`profile`](#-clickhouse--server--user--profile)
* [`allow_databases`](#-clickhouse--server--user--allow_databases)
* [`networks`](#-clickhouse--server--user--networks)
* [`users_dir`](#-clickhouse--server--user--users_dir)
* [`user_file_owner`](#-clickhouse--server--user--user_file_owner)
* [`user_file_group`](#-clickhouse--server--user--user_file_group)
* [`ensure`](#-clickhouse--server--user--ensure)

##### <a name="-clickhouse--server--user--name"></a>`name`

Name of the Clickhouse user. Will be also used as a file name for user configuration file in $users_dir folder.

##### <a name="-clickhouse--server--user--password"></a>`password`

Data type: `Optional[String]`

Password for Clickhouse user. Can be specified in plaintext (and later hashed using sha256) or in sha256 format.

Default value: `undef`

##### <a name="-clickhouse--server--user--quota"></a>`quota`

Data type: `String`

Name of the quota for user.

Default value: `'default'`

##### <a name="-clickhouse--server--user--profile"></a>`profile`

Data type: `String`

Name of the profile for user.

Default value: `'default'`

##### <a name="-clickhouse--server--user--allow_databases"></a>`allow_databases`

Data type: `Optional[Array[String]]`

Array of databases, the user will have permissions to access.

Default value: `undef`

##### <a name="-clickhouse--server--user--networks"></a>`networks`

Data type: `Optional[Clickhouse::Clickhouse_networks]`

Clickhouse::Clickhouse_networks (see types/clickhouse_networks.pp) Restrictions for ip\hosts for user.

Default value: `undef`

##### <a name="-clickhouse--server--user--users_dir"></a>`users_dir`

Data type: `Stdlib::Unixpath`

Path to directory, where user configuration will be stored. Defaults to '/etc/clickhouse-server/conf.d/'

Default value: `$clickhouse::server::config_dir`

##### <a name="-clickhouse--server--user--user_file_owner"></a>`user_file_owner`

Data type: `String`

Owner of the user file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_user`

##### <a name="-clickhouse--server--user--user_file_group"></a>`user_file_group`

Data type: `String`

Group of the user file. Defaults to 'clickhouse'.

Default value: `$clickhouse::server::clickhouse_group`

##### <a name="-clickhouse--server--user--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether to create user. Valid values are 'present', 'absent'. Defaults to 'present'.

Default value: `'present'`

## Resource types

### <a name="clickhouse_database"></a>`clickhouse_database`

Manages a Clickhouse database.

#### Properties

The following properties are available in the `clickhouse_database` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `clickhouse_database` type.

* [`name`](#-clickhouse_database--name)
* [`provider`](#-clickhouse_database--provider)

##### <a name="-clickhouse_database--name"></a>`name`

namevar

The name of the Clickhouse database to manage.

##### <a name="-clickhouse_database--provider"></a>`provider`

The specific backend to use for this `clickhouse_database` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

## Functions

### <a name="clickhouse_config"></a>`clickhouse_config`

Type: Ruby 3.x API

Convert hash to Clickhouse XML config.

#### `clickhouse_config(Hash $Settings)`

The clickhouse_config function.

Returns: `Xml` Сlickhouse XML configuration.

##### `Settings`

Data type: `Hash`

for Clickhouse Server.

## Data types

### <a name="Clickhouse--Clickhouse_crash_reports"></a>`Clickhouse::Clickhouse_crash_reports`

lint:ignore:2sp_soft_tabs

Alias of

```puppet
Struct[{enabled => Boolean,
                                                  Optional[endpoint]  => String,
                                                  Optional[anonymize] => Boolean,
                                                  Optional[http_proxy] => String,
                                                  Optional[debug] => Boolean,
                                                  Optional[tmp_path] => String
                                                  }]
```

### <a name="Clickhouse--Clickhouse_networks"></a>`Clickhouse::Clickhouse_networks`

lint:ignore:2sp_soft_tabs

Alias of

```puppet
Struct[{Optional[ip]          => Array[String],
                                               Optional[host]        => Array[String],
                                               Optional[host_regexp] => Array[String]}]
```

### <a name="Clickhouse--Clickhouse_quotas"></a>`Clickhouse::Clickhouse_quotas`

lint:ignore:2sp_soft_tabs

Alias of

```puppet
Hash[String, Struct[{interval => Array[Struct[{Optional[duration]       => Integer,
                                                                                    Optional[queries]        => Integer,
                                                                                    Optional[errors]         => Integer,
                                                                                    Optional[result_rows]    => Integer,
                                                                                    Optional[read_rows]      => Integer,
                                                                                    Optional[execution_time] => Integer}]]}]]
```

### <a name="Clickhouse--Clickhouse_remote_servers"></a>`Clickhouse::Clickhouse_remote_servers`

lint:ignore:2sp_soft_tabs, lint:ignore:140chars

Alias of

```puppet
Hash[String, Hash[
                                                String,Struct[{
                                                  Optional[weight] => Integer,
                                                  Optional[internal_replication] => Boolean,
                                                  Optional[replication_user]     => String,
                                                  Optional[replication_password] => String,
                                                  Optional[replica]              => Array[Pattern['[^\:]+:[0-9]{1,5}']],
                                                  Optional[replicas]             => Hash[
                                                    String, Struct[{
                                                      Optional[port]             => Integer,
                                                      Optional[priority]         => Integer,
                                                      Optional[secure]           => Integer,
                                                      Optional[default_database] => String,
                                                      Optional[tcp_port_secure]  => Integer,
                                                      Optional[user]             => String,
                                                      Optional[password]         => String,
                                                    }]
                                                  ]
                                                }]
                                              ]]
```

### <a name="Clickhouse--Clickhouse_replication"></a>`Clickhouse::Clickhouse_replication`

lint:ignore:2sp_soft_tabs

Alias of

```puppet
Struct[{zookeeper_servers => Array[Pattern['[^\:]+:[0-9]{1,5}']],
                                                  Optional[macros]  => Hash[String, Any],
                                                  Optional[distributed_ddl] => Struct[{
                                                      Optional[path] => String,
                                                      Optional[profile] => String,
                                                    }]
                                                  }]
```

### <a name="Clickhouse--Clickhouse_users"></a>`Clickhouse::Clickhouse_users`

lint:ignore:2sp_soft_tabs

Alias of

```puppet
Hash[String, Struct[{Optional[password]        => String,
                                                         Optional[quota]           => String,
                                                         Optional[profile]         => String,
                                                         Optional[allow_databases] => Array[String],
                                                         Optional[networks]        => Clickhouse::Clickhouse_networks,
                                                         Optional[users_dir]       => Stdlib::Unixpath,
                                                         Optional[user_file_owner] => String,
                                                         Optional[user_file_group] => String,
                                                         Optional[ensure]          => String}], 1]
```

